==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/HrefHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HttpMethod;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ HrefHints.JSON_PROPERTY_ALLOW })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class HrefHints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<HttpMethod> allow = null;

    public HrefHints() {
    }

    public HrefHints allow(List<HttpMethod> allow) {

        this.allow = allow;
        return this;
    }

    public HrefHints addallowItem(HttpMethod allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HttpMethod> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<HttpMethod> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        HrefHints hrefHints = (HrefHints) o;
        return Objects.equals(this.allow, hrefHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class HrefHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/HrefHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HttpMethod;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ HrefHints.JSON_PROPERTY_ALLOW })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class HrefHints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<HttpMethod> allow = null;

    public HrefHints() {
    }

    public HrefHints allow(List<HttpMethod> allow) {

        this.allow = allow;
        return this;
    }

    public HrefHints addallowItem(HttpMethod allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HttpMethod> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<HttpMethod> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        HrefHints hrefHints = (HrefHints) o;
        return Objects.equals(this.allow, hrefHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class HrefHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
